==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/sblock/topic.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");

$VAR["Heading"] = _TOPICS;
$VAR["Content"] = "";
$topics_nrows	= count($TOPIC);
if ($CONF["TopicSort"]=="brief") {
   $numtops	= $topics_nrows;
   $topics_nrows	= 5;
} $numtops = 0;
foreach ($TOPIC as $A) {
   $foo	= $A['Topic'];
   if ($CONF['SHOW_NUM']) $cmt = " (". KWL_NumsByTopic($A['Rid']) .")";
   $VAR['Content'] .= $A['Rid']==$topic ? sprintf("$CONF[dotchar]<B>%s</B>%s<BR>\n",$foo,$cmt) : sprintf("$CONF[dotchar]<A HREF=\"$CONF[G_URL]/stories.php?topic=%s\">%s</A>%s<BR>",$A['Rid'],$foo,$cmt);
}
if ($numtops>$topics_nrows) $VAR['Content']	.= "<BR><DIV ALIGN=RIGHT><A HREF=\"$CONF[G_URL]/topics.php\">". _MORE ." &gt;&gt;</A></DIV>";
if ($CONF['show_total_num']) {
   $VAR['Content'] .= "<P>" . _TOTALSTORIES . ": ". number_format($TOTAL_STORY);
   $VAR['Content'] .= "<BR>" . _TOTALCOMMENTS . ": ". number_format(SqlCount("T_Comments"));
}
$VAR['Display'] =& $align;
KWL_DrawBlock($VAR);
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/sblock/topic.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");

$VAR["Heading"] = _TOPICS;
$VAR["Content"] = "";
$topics_nrows	= count($TOPIC);
if ($CONF["TopicSort"]=="brief") {
   $numtops	= $topics_nrows;
   $topics_nrows	= 5;
} $numtops = 0;
foreach ($TOPIC as $A) {
   $foo	= $A['Topic'];
   if ($CONF['SHOW_NUM']) $cmt = " (". KWL_NumsByTopic($A['Rid']) .")";
   $VAR['Content'] .= $A['Rid']==$topic ? sprintf("$CONF[dotchar]<b>%s</b>%s<br />\n",$foo,$cmt) : sprintf("$CONF[dotchar]<a href=\"$CONF[G_URL]/stories.php?topic=%s\">%s</a>%s<br />",$A['Rid'],$foo,$cmt);
}
if ($numtops>$topics_nrows) $VAR['Content']	.= "<br /><div align=\"right\"><a href=\"$CONF[G_URL]/topics.php\">". _MORE ." &gt;&gt;</a></div>";
if ($CONF['show_total_num']) {
   $VAR['Content'] .= "<br />" . _TOTALSTORIES . ": ". number_format($TOTAL_STORY);
   $VAR['Content'] .= "<br />" . _TOTALCOMMENTS . ": ". number_format(SqlCount("T_Comments"));
}
$VAR['Display'] =& $align;
KWL_DrawBlock($VAR);
?>
